@@ -1,5 +1,7 @@
 use rusty_engine::prelude::*;
 
+rusty_engine::init!();
+
 fn main() {
     let mut game = Game::new();
     game.window_settings(WindowDescriptor {
@@ -16,11 +18,11 @@ fn main() {
         resizable: true,
         decorations: false,
         cursor_visible: false,
-        ..Default::default()
+        ..Default::default() // for the rest of the options, see https://docs.rs/bevy/0.5.0/bevy/window/struct.WindowDescriptor.html
     });
-    let _ = game.add_text_actor(
+    let _ = game.add_text(
         "message",
         "This is a heavily-customized window.\nYou may resize it a little bit.\nPress Esc to exit.",
     );
-    game.run(|_| {});
+    game.run(());
 }
