@@ -1,4 +1,4 @@
-use crate::prelude::GameState;
+use crate::prelude::EngineState;
 use bevy::{prelude::*, utils::HashSet};
 
 // Re-export some Bevy types to use
@@ -26,7 +26,7 @@ impl Plugin for MousePlugin {
 ///
 /// If you need to process all mouse events that occurred during a single frame, use the
 /// `mouse_button_events`, `mouse_location_events`, `mouse_motion_events`, or `mouse_wheel_events`
-/// fields on [`GameState`](crate::prelude::GameState).
+/// fields on [`EngineState`](crate::prelude::EngineState).
 #[derive(Clone, Debug, Default)]
 pub struct MouseState {
     location: Option<Vec2>,
@@ -40,38 +40,38 @@ pub struct MouseState {
 /// A simplification of mouse wheel events for a frame into a single state. Unless you are treating
 /// the mouse wheel as if scrolling in a direction were equivalent to clicking a mouse button, you
 /// probably want to use
-/// [`GameState::mouse_wheel_events`](crate::prelude::GameState::mouse_wheel_events) instead.
+/// [`EngineState::mouse_wheel_events`](crate::prelude::EngineState::mouse_wheel_events) instead.
 #[derive(Clone, Copy, Debug, Default)]
 pub struct MouseWheelState {
     /// The y component of the mouse wheel movement. This is the "normal" scrolling direction of a
     /// typical mouse wheel. This will be either `-1.0`, `0.0`, or `1.0`. For fine-grained
     /// mouse wheel info, see
-    /// [`GameState::mouse_wheel_events`](crate::prelude::GameState::mouse_wheel_events) instead.
+    /// [`EngineState::mouse_wheel_events`](crate::prelude::EngineState::mouse_wheel_events) instead.
     pub y: f32,
     /// The x component of the mouse wheel movement. This is usually caused by holding the shift key
     /// while scrolling the mouse on regular mice, or by a horizontal scroll wheel on exotic mice.
     /// This will be either `-1.0`, `0.0`, or `1.0`. For fine-grained mouse wheel info, see
-    /// [`GameState::mouse_wheel_events`](crate::prelude::GameState::mouse_wheel_events) instead.
+    /// [`EngineState::mouse_wheel_events`](crate::prelude::EngineState::mouse_wheel_events) instead.
     pub x: f32,
 }
 
 impl MouseState {
     /// Final location of the mouse this frame. If you want to process _all_ the locations the mouse
     /// was at during this frame, see
-    /// [`GameState::mouse_location_events`](crate::prelude::GameState::mouse_location_events)
+    /// [`EngineState::mouse_location_events`](crate::prelude::EngineState::mouse_location_events)
     /// instead.
     pub fn location(&self) -> Option<Vec2> {
         self.location
     }
     /// The cumulative relative motion of the mouse this frame. If you want to process _all_ the
     /// individual relative motions, see
-    /// [`GameState::mouse_motion_events](crate::prelude::GameState::mouse_motion_events) instead.
+    /// [`EngineState::mouse_motion_events](crate::prelude::EngineState::mouse_motion_events) instead.
     pub fn motion(&self) -> Vec2 {
         self.motion
     }
     /// Returns a [`MouseWheelState], which is a simplified version of cumulative mouse wheel
     /// events. When dealing with mouse wheel movement, you _usually_ don't want this...you want
-    /// [`GameState::mouse_wheel_events`](crate::prelude::GameState::mouse_wheel_events) instead.
+    /// [`EngineState::mouse_wheel_events`](crate::prelude::EngineState::mouse_wheel_events) instead.
     pub fn wheel(&self) -> MouseWheelState {
         self.wheel
     }
@@ -87,22 +87,22 @@ impl MouseState {
     pub fn just_released(&self, mouse_button: MouseButton) -> bool {
         self.just_released.contains(&mouse_button)
     }
-    /// Returns an iterator over all the mouse buttons were being pressed at the end of the last frame
-    pub fn get_pressed(&self) -> impl ExactSizeIterator<Item = &MouseButton> {
-        self.pressed.iter()
+    /// Returns true if any of the indicated mouse buttons were pressed
+    pub fn pressed_any(&self, mouse_buttons: &[MouseButton]) -> bool {
+        mouse_buttons.iter().any(|k| self.pressed(*k))
     }
-    /// Returns an iterator over all the mouse buttons that started being pressed at the end of the last frame
-    pub fn get_just_pressed(&self) -> impl ExactSizeIterator<Item = &MouseButton> {
-        self.just_pressed.iter()
+    /// Returns true if any of the indicated mouse buttons were just pressed this frame
+    pub fn just_pressed_any(&self, mouse_buttons: &[MouseButton]) -> bool {
+        mouse_buttons.iter().any(|k| self.just_pressed(*k))
     }
-    /// Returns an iterator over all the mouse buttons that started being released at the end of the last frame
-    pub fn get_just_released(&self) -> impl ExactSizeIterator<Item = &MouseButton> {
-        self.just_released.iter()
+    /// Returns true if any of the indicated mouse buttons were just released this frame
+    pub fn just_released_any(&self, mouse_buttons: &[MouseButton]) -> bool {
+        mouse_buttons.iter().any(|k| self.just_released(*k))
     }
 }
 
 fn sync_mouse_events(
-    mut game_state: ResMut<GameState>,
+    mut game_state: ResMut<EngineState>,
     mut mouse_button_events: EventReader<MouseButtonInput>,
     mut cursor_moved_events: EventReader<CursorMoved>,
     mut mouse_motion_events: EventReader<MouseMotion>,
@@ -122,7 +122,7 @@ fn sync_mouse_events(
         let mut new_event = ev.clone();
         // Convert from screen space to game space
         // TODO: Check to see if this needs to be adjusted for different DPIs
-        new_event.position -= game_state.screen_dimensions * 0.5;
+        new_event.position -= game_state.window_dimensions * 0.5;
         game_state.mouse_location_events.push(new_event);
     }
     for ev in mouse_motion_events.iter() {
@@ -141,13 +141,13 @@ fn sync_mouse_state(
     mut mouse_motion_events: EventReader<MouseMotion>,
     mut cursor_moved_events: EventReader<CursorMoved>,
     mut mouse_wheel_events: EventReader<MouseWheel>,
-    game_state: Res<GameState>,
+    game_state: Res<EngineState>,
 ) {
     // Sync the current mouse location, which will be the last cursor_moved event that occurred.
     // Only changes when we get a new event, otherwise we preserve the last location.
     if let Some(event) = cursor_moved_events.iter().last() {
         // Convert from bevy's window space to our game space
-        let location = event.position - game_state.screen_dimensions * 0.5;
+        let location = event.position - game_state.window_dimensions * 0.5;
         mouse_state.location = Some(location);
     }
     // Sync the relative mouse motion. This is the cumulative relative motion during the last frame.
